from django.template import Library

register = Library()

try:
    # Django < 1.9.0
    from django.templatetags.future import url
except ImportError:
    from django.template.defaulttags import url



# Unused imports below are exposed as API.
from .utils import get_tree_item_model, get_tree_model, tree, item, import_app_sitetree_module, \
    import_project_sitetree_modules
from .sitetreeapp import register_i18n_trees, register_items_hook, compose_dynamic_tree, register_dynamic_trees, \
    get_dynamic_trees
from .fields import TreeItemChoiceField
from .forms import TreeItemForm
